/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type atanf_vec[] = {
{39, 0,123,__LINE__, 0xbfec08aa, 0xef14d674, 0xbff33333, 0x33333333},	/* -0.876058=f(-1.2)*/
{40, 0,123,__LINE__, 0xbfebe6ed, 0xa099d4f5, 0xbff30a3d, 0x70a3d70a},	/* -0.871939=f(-1.19)*/
{39, 0,123,__LINE__, 0xbfebc4da, 0xb6b46cf5, 0xbff2e147, 0xae147ae1},	/* -0.86778=f(-1.18)*/
{39, 0,123,__LINE__, 0xbfeba271, 0x6e6a37ff, 0xbff2b851, 0xeb851eb8},	/* -0.863579=f(-1.17)*/
{39, 0,123,__LINE__, 0xbfeb7fb0, 0xb334cfe9, 0xbff28f5c, 0x28f5c28f},	/* -0.859337=f(-1.16)*/
{41, 0,123,__LINE__, 0xbfeb5c97, 0x8947134c, 0xbff26666, 0x66666666},	/* -0.855053=f(-1.15)*/
{40, 0,123,__LINE__, 0xbfeb3924, 0xf31f37a6, 0xbff23d70, 0xa3d70a3d},	/* -0.850726=f(-1.14)*/
{40, 0,123,__LINE__, 0xbfeb1557, 0xf1973031, 0xbff2147a, 0xe147ae14},	/* -0.846355=f(-1.13)*/
{40, 0,123,__LINE__, 0xbfeaf12f, 0x83f648d5, 0xbff1eb85, 0x1eb851eb},	/* -0.841942=f(-1.12)*/
{40, 0,123,__LINE__, 0xbfeaccaa, 0xa804020a, 0xbff1c28f, 0x5c28f5c2},	/* -0.837484=f(-1.11)*/
{44, 0,123,__LINE__, 0xbfeaa7c8, 0x5a1c3ad1, 0xbff19999, 0x99999999},	/* -0.832981=f(-1.1)*/
{41, 0,123,__LINE__, 0xbfea8287, 0x9544b647, 0xbff170a3, 0xd70a3d70},	/* -0.828434=f(-1.09)*/
{40, 0,123,__LINE__, 0xbfea5ce7, 0x53440a81, 0xbff147ae, 0x147ae147},	/* -0.823841=f(-1.08)*/
{42, 0,123,__LINE__, 0xbfea36e6, 0x8cba06da, 0xbff11eb8, 0x51eb851e},	/* -0.819202=f(-1.07)*/
{42, 0,123,__LINE__, 0xbfea1084, 0x1b166c9a, 0xbff0f5c2, 0x8f5c28f5},	/* -0.814516=f(-1.06)*/
{41, 0,123,__LINE__, 0xbfe9e9bf, 0x30f3cf55, 0xbff0cccc, 0xcccccccc},	/* -0.809784=f(-1.05)*/
{41, 0,123,__LINE__, 0xbfe9c296, 0xa648fc14, 0xbff0a3d7, 0x0a3d70a3},	/* -0.805003=f(-1.04)*/
{43, 0,123,__LINE__, 0xbfe99b09, 0x702df464, 0xbff07ae1, 0x47ae147a},	/* -0.800175=f(-1.03)*/
{44, 0,123,__LINE__, 0xbfe97316, 0x8325efd2, 0xbff051eb, 0x851eb851},	/* -0.795299=f(-1.02)*/
{43, 0,123,__LINE__, 0xbfe94abc, 0xd341c3fc, 0xbff028f5, 0xc28f5c28},	/* -0.790373=f(-1.01)*/
{64, 0,123,__LINE__, 0xbfe921fb, 0x54442d18, 0xbfefffff, 0xfffffffe},	/* -0.785398=f(-1)*/
{44, 0,123,__LINE__, 0xbfe8f8d0, 0xf9c806ac, 0xbfefae14, 0x7ae147ac},	/* -0.780373=f(-0.99)*/
{42, 0,123,__LINE__, 0xbfe8cf3c, 0xb7688432, 0xbfef5c28, 0xf5c28f5a},	/* -0.775298=f(-0.98)*/
{42, 0,123,__LINE__, 0xbfe8a53d, 0x80eb7985, 0xbfef0a3d, 0x70a3d708},	/* -0.770171=f(-0.97)*/
{41, 0,123,__LINE__, 0xbfe87ad2, 0x39c6a5ae, 0xbfeeb851, 0xeb851eb6},	/* -0.764993=f(-0.96)*/
{41, 0,123,__LINE__, 0xbfe84ff9, 0xf7bff26b, 0xbfee6666, 0x66666664},	/* -0.759763=f(-0.95)*/
{42, 0,123,__LINE__, 0xbfe824b3, 0x9fb39920, 0xbfee147a, 0xe147ae12},	/* -0.75448=f(-0.94)*/
{40, 0,123,__LINE__, 0xbfe7f8fe, 0x27e4271c, 0xbfedc28f, 0x5c28f5c0},	/* -0.749145=f(-0.93)*/
{43, 0,123,__LINE__, 0xbfe7ccd8, 0x87b34764, 0xbfed70a3, 0xd70a3d6e},	/* -0.743756=f(-0.92)*/
{40, 0,123,__LINE__, 0xbfe7a041, 0xb7d9b23c, 0xbfed1eb8, 0x51eb851c},	/* -0.738313=f(-0.91)*/
{41, 0,123,__LINE__, 0xbfe77338, 0xa0f3a0bc, 0xbfeccccc, 0xccccccca},	/* -0.732815=f(-0.9)*/
{42, 0,123,__LINE__, 0xbfe745bc, 0x62486ac9, 0xbfec7ae1, 0x47ae1478},	/* -0.727263=f(-0.89)*/
{40, 0,123,__LINE__, 0xbfe717cb, 0xe87d80d6, 0xbfec28f5, 0xc28f5c26},	/* -0.721655=f(-0.88)*/
{41, 0,123,__LINE__, 0xbfe6e966, 0x3409a5e1, 0xbfebd70a, 0x3d70a3d4},	/* -0.715991=f(-0.87)*/
{42, 0,123,__LINE__, 0xbfe6ba8a, 0x47f8aa01, 0xbfeb851e, 0xb851eb82},	/* -0.710271=f(-0.86)*/
{42, 0,123,__LINE__, 0xbfe68b37, 0x2a33099d, 0xbfeb3333, 0x33333330},	/* -0.704494=f(-0.85)*/
{40, 0,123,__LINE__, 0xbfe65b6b, 0xd10553f8, 0xbfeae147, 0xae147ade},	/* -0.69866=f(-0.84)*/
{39, 0,123,__LINE__, 0xbfe62b27, 0x6e49e7a0, 0xbfea8f5c, 0x28f5c28c},	/* -0.692768=f(-0.83)*/
{41, 0,123,__LINE__, 0xbfe5fa68, 0xffb51ff8, 0xbfea3d70, 0xa3d70a3a},	/* -0.686818=f(-0.82)*/
{39, 0,123,__LINE__, 0xbfe5c92f, 0x99a68d3b, 0xbfe9eb85, 0x1eb851e8},	/* -0.680809=f(-0.81)*/
{41, 0,123,__LINE__, 0xbfe5977a, 0x54eaf0d0, 0xbfe99999, 0x99999996},	/* -0.674741=f(-0.8)*/
{40, 0,123,__LINE__, 0xbfe56548, 0x4f150748, 0xbfe947ae, 0x147ae144},	/* -0.668614=f(-0.79)*/
{40, 0,123,__LINE__, 0xbfe53298, 0x96f3ffb4, 0xbfe8f5c2, 0x8f5c28f2},	/* -0.662426=f(-0.78)*/
{38, 0,123,__LINE__, 0xbfe4ff6a, 0x7c55a213, 0xbfe8a3d7, 0x0a3d70a0},	/* -0.656179=f(-0.77)*/
{37, 0,123,__LINE__, 0xbfe4cbbd, 0x199cb989, 0xbfe851eb, 0x851eb84e},	/* -0.64987=f(-0.76)*/
{39, 0,123,__LINE__, 0xbfe4978f, 0xa3269ee1, 0xbfe7ffff, 0xfffffffc},	/* -0.643501=f(-0.75)*/
{40, 0,123,__LINE__, 0xbfe462e1, 0x53fea64b, 0xbfe7ae14, 0x7ae147aa},	/* -0.63707=f(-0.74)*/
{42, 0,123,__LINE__, 0xbfe42db1, 0x6e4875a8, 0xbfe75c28, 0xf5c28f58},	/* -0.630578=f(-0.73)*/
{38, 0,123,__LINE__, 0xbfe3f7ff, 0x3bad3381, 0xbfe70a3d, 0x70a3d706},	/* -0.624023=f(-0.72)*/
{39, 0,123,__LINE__, 0xbfe3c1c9, 0xf8850ff6, 0xbfe6b851, 0xeb851eb4},	/* -0.617406=f(-0.71)*/
{38, 0,123,__LINE__, 0xbfe38b11, 0x29303bc3, 0xbfe66666, 0x66666662},	/* -0.610726=f(-0.7)*/
{38, 0,123,__LINE__, 0xbfe353d4, 0x1b8000de, 0xbfe6147a, 0xe147ae10},	/* -0.603983=f(-0.69)*/
{38, 0,123,__LINE__, 0xbfe31c12, 0x3bae5fc0, 0xbfe5c28f, 0x5c28f5be},	/* -0.597177=f(-0.68)*/
{38, 0,123,__LINE__, 0xbfe2e3ca, 0xffc55cd9, 0xbfe570a3, 0xd70a3d6c},	/* -0.590307=f(-0.67)*/
{39, 0,123,__LINE__, 0xbfe2aafd, 0xe81bd50c, 0xbfe51eb8, 0x51eb851a},	/* -0.583373=f(-0.66)*/
{37, 0,123,__LINE__, 0xbfe271aa, 0x6955b200, 0xbfe4cccc, 0xccccccc8},	/* -0.576375=f(-0.65)*/
{40, 0,123,__LINE__, 0xbfe237d0, 0x46abe6ab, 0xbfe47ae1, 0x47ae1476},	/* -0.569313=f(-0.64)*/
{39, 0,123,__LINE__, 0xbfe1fd6f, 0x0c144c54, 0xbfe428f5, 0xc28f5c24},	/* -0.562187=f(-0.63)*/
{38, 0,123,__LINE__, 0xbfe1c286, 0x68243c6c, 0xbfe3d70a, 0x3d70a3d2},	/* -0.554996=f(-0.62)*/
{38, 0,123,__LINE__, 0xbfe18716, 0x164cc043, 0xbfe3851e, 0xb851eb80},	/* -0.54774=f(-0.61)*/
{39, 0,123,__LINE__, 0xbfe14b1d, 0xdf627649, 0xbfe33333, 0x3333332e},	/* -0.54042=f(-0.6)*/
{38, 0,123,__LINE__, 0xbfe10e9d, 0x8269ecb9, 0xbfe2e147, 0xae147adc},	/* -0.533034=f(-0.59)*/
{37, 0,123,__LINE__, 0xbfe0d195, 0x13df3464, 0xbfe28f5c, 0x28f5c28a},	/* -0.525584=f(-0.58)*/
{37, 0,123,__LINE__, 0xbfe09404, 0x7073e5d6, 0xbfe23d70, 0xa3d70a38},	/* -0.518069=f(-0.57)*/
{38, 0,123,__LINE__, 0xbfe055eb, 0x9bed5ef9, 0xbfe1eb85, 0x1eb851e6},	/* -0.510488=f(-0.56)*/
{39, 0,123,__LINE__, 0xbfe0174a, 0xaa285063, 0xbfe19999, 0x99999994},	/* -0.502843=f(-0.55)*/
{35, 0,123,__LINE__, 0xbfdfb043, 0x7f47297b, 0xbfe147ae, 0x147ae142},	/* -0.495133=f(-0.54)*/
{38, 0,123,__LINE__, 0xbfdf30e1, 0xf21de795, 0xbfe0f5c2, 0x8f5c28f0},	/* -0.487359=f(-0.53)*/
{39, 0,123,__LINE__, 0xbfdeb071, 0x9f1b3dcf, 0xbfe0a3d7, 0x0a3d709e},	/* -0.479519=f(-0.52)*/
{39, 0,123,__LINE__, 0xbfde2ef3, 0x07efdc1b, 0xbfe051eb, 0x851eb84c},	/* -0.471616=f(-0.51)*/
{36, 0,123,__LINE__, 0xbfddac67, 0x0561bb4f, 0xbfdfffff, 0xfffffff4},	/* -0.463648=f(-0.5)*/
{36, 0,123,__LINE__, 0xbfdd28ce, 0x96c784ce, 0xbfdf5c28, 0xf5c28f50},	/* -0.455616=f(-0.49)*/
{37, 0,123,__LINE__, 0xbfdca42a, 0xc909f465, 0xbfdeb851, 0xeb851eac},	/* -0.44752=f(-0.48)*/
{43, 0,123,__LINE__, 0xbfdc1e7d, 0x1f75747d, 0xbfde147a, 0xe147ae08},	/* -0.439361=f(-0.47)*/
{36, 0,123,__LINE__, 0xbfdb97c6, 0xf9406ab4, 0xbfdd70a3, 0xd70a3d64},	/* -0.431139=f(-0.46)*/
{38, 0,123,__LINE__, 0xbfdb1009, 0xdf497c65, 0xbfdccccc, 0xccccccc0},	/* -0.422854=f(-0.45)*/
{38, 0,123,__LINE__, 0xbfda8747, 0xd56eb412, 0xbfdc28f5, 0xc28f5c1c},	/* -0.414507=f(-0.44)*/
{36, 0,123,__LINE__, 0xbfd9fd82, 0xbc57a5dd, 0xbfdb851e, 0xb851eb78},	/* -0.406098=f(-0.43)*/
{38, 0,123,__LINE__, 0xbfd972bc, 0xa0ebf527, 0xbfdae147, 0xae147ad4},	/* -0.397628=f(-0.42)*/
{35, 0,123,__LINE__, 0xbfd8e6f8, 0x0f4c9bee, 0xbfda3d70, 0xa3d70a30},	/* -0.389097=f(-0.41)*/
{35, 0,123,__LINE__, 0xbfd85a37, 0x70ebe7ae, 0xbfd99999, 0x9999998c},	/* -0.380506=f(-0.4)*/
{36, 0,123,__LINE__, 0xbfd7cc7d, 0x5daadfdb, 0xbfd8f5c2, 0x8f5c28e8},	/* -0.371856=f(-0.39)*/
{39, 0,123,__LINE__, 0xbfd73dcc, 0xf05da4a1, 0xbfd851eb, 0x851eb844},	/* -0.363147=f(-0.38)*/
{37, 0,123,__LINE__, 0xbfd6ae29, 0x21408626, 0xbfd7ae14, 0x7ae147a0},	/* -0.35438=f(-0.37)*/
{37, 0,123,__LINE__, 0xbfd61d95, 0x34fc23bb, 0xbfd70a3d, 0x70a3d6fc},	/* -0.345556=f(-0.36)*/
{35, 0,123,__LINE__, 0xbfd58c14, 0x84f62c77, 0xbfd66666, 0x66666658},	/* -0.336675=f(-0.35)*/
{37, 0,123,__LINE__, 0xbfd4f9aa, 0xf181f793, 0xbfd5c28f, 0x5c28f5b4},	/* -0.327739=f(-0.34)*/
{36, 0,123,__LINE__, 0xbfd4665c, 0x379e6ef3, 0xbfd51eb8, 0x51eb8510},	/* -0.318748=f(-0.33)*/
{37, 0,123,__LINE__, 0xbfd3d22c, 0x459ac510, 0xbfd47ae1, 0x47ae146c},	/* -0.309703=f(-0.32)*/
{36, 0,123,__LINE__, 0xbfd33d1f, 0x92caa76b, 0xbfd3d70a, 0x3d70a3c8},	/* -0.300606=f(-0.31)*/
{37, 0,123,__LINE__, 0xbfd2a73a, 0x71dcec16, 0xbfd33333, 0x33333324},	/* -0.291457=f(-0.3)*/
{36, 0,123,__LINE__, 0xbfd21081, 0x66d9dcb1, 0xbfd28f5c, 0x28f5c280},	/* -0.282257=f(-0.29)*/
{35, 0,123,__LINE__, 0xbfd178f9, 0x8001d41a, 0xbfd1eb85, 0x1eb851dc},	/* -0.273009=f(-0.28)*/
{35, 0,123,__LINE__, 0xbfd0e0a7, 0xa4e2165e, 0xbfd147ae, 0x147ae138},	/* -0.263712=f(-0.27)*/
{36, 0,123,__LINE__, 0xbfd04790, 0xed91143f, 0xbfd0a3d7, 0x0a3d7094},	/* -0.254368=f(-0.26)*/
{37, 0,123,__LINE__, 0xbfcf5b75, 0xf92c80dd, 0xbfcfffff, 0xffffffe0},	/* -0.244979=f(-0.25)*/
{36, 0,123,__LINE__, 0xbfce2656, 0x7792ede2, 0xbfceb851, 0xeb851e98},	/* -0.235545=f(-0.24)*/
{35, 0,123,__LINE__, 0xbfccefcf, 0x1f0e713a, 0xbfcd70a3, 0xd70a3d50},	/* -0.226068=f(-0.23)*/
{41, 0,123,__LINE__, 0xbfcbb7eb, 0x9c76b83b, 0xbfcc28f5, 0xc28f5c08},	/* -0.21655=f(-0.22)*/
{38, 0,123,__LINE__, 0xbfca7eb8, 0x52dd8b57, 0xbfcae147, 0xae147ac0},	/* -0.206992=f(-0.21)*/
{37, 0,123,__LINE__, 0xbfc94441, 0xff1e8881, 0xbfc99999, 0x99999978},	/* -0.197396=f(-0.2)*/
{36, 0,123,__LINE__, 0xbfc80895, 0x58e9b95a, 0xbfc851eb, 0x851eb830},	/* -0.187762=f(-0.19)*/
{39, 0,123,__LINE__, 0xbfc6cbbf, 0xe78dc0ed, 0xbfc70a3d, 0x70a3d6e8},	/* -0.178093=f(-0.18)*/
{36, 0,123,__LINE__, 0xbfc58dcf, 0x08b0cbf1, 0xbfc5c28f, 0x5c28f5a0},	/* -0.16839=f(-0.17)*/
{40, 0,123,__LINE__, 0xbfc44ed0, 0xc5b9e4fb, 0xbfc47ae1, 0x47ae1458},	/* -0.158655=f(-0.16)*/
{36, 0,123,__LINE__, 0xbfc30ed3, 0x745c7ec6, 0xbfc33333, 0x33333310},	/* -0.14889=f(-0.15)*/
{39, 0,123,__LINE__, 0xbfc1cde5, 0x55175feb, 0xbfc1eb85, 0x1eb851c8},	/* -0.139096=f(-0.14)*/
{37, 0,123,__LINE__, 0xbfc08c15, 0x4b37fcc9, 0xbfc0a3d7, 0x0a3d7080},	/* -0.129275=f(-0.13)*/
{38, 0,123,__LINE__, 0xbfbe92e4, 0xd816b510, 0xbfbeb851, 0xeb851e71},	/* -0.119429=f(-0.12)*/
{39, 0,123,__LINE__, 0xbfbc0c17, 0xd5ee1017, 0xbfbc28f5, 0xc28f5be2},	/* -0.10956=f(-0.11)*/
{38, 0,123,__LINE__, 0xbfb983e2, 0x8938f9ec, 0xbfb99999, 0x99999953},	/* -0.0996687=f(-0.1)*/
{36, 0,123,__LINE__, 0xbfb6fa64, 0x55ee5c13, 0xbfb70a3d, 0x70a3d6c4},	/* -0.0897582=f(-0.09)*/
{36, 0,123,__LINE__, 0xbfb46fbc, 0xe23e3843, 0xbfb47ae1, 0x47ae1435},	/* -0.07983=f(-0.08)*/
{36, 0,123,__LINE__, 0xbfb1e40c, 0x8cbe24e8, 0xbfb1eb85, 0x1eb851a6},	/* -0.069886=f(-0.07)*/
{36, 0,123,__LINE__, 0xbfaeaee7, 0x293b5294, 0xbfaeb851, 0xeb851e2d},	/* -0.0599282=f(-0.06)*/
{38, 0,123,__LINE__, 0xbfa99425, 0x9df4ef97, 0xbfa99999, 0x9999990e},	/* -0.0499584=f(-0.05)*/
{37, 0,123,__LINE__, 0xbfa47816, 0x1bcb9ce0, 0xbfa47ae1, 0x47ae13ef},	/* -0.0399787=f(-0.04)*/
{36, 0,123,__LINE__, 0xbf9eb5f6, 0x38a0d3a8, 0xbf9eb851, 0xeb851da0},	/* -0.029991=f(-0.03)*/
{36, 0,123,__LINE__, 0xbf947a2e, 0x5602b3cb, 0xbf947ae1, 0x47ae1362},	/* -0.0199973=f(-0.02)*/
{37, 0,123,__LINE__, 0xbf847ab4, 0x83711936, 0xbf847ae1, 0x47ae1249},	/* -0.00999967=f(-0.01)*/
{64, 0,123,__LINE__, 0x3cd19000, 0x00000000, 0x3cd19000, 0x00000000},	/* 9.74915e-16=f(9.74915e-16)*/
{37, 0,123,__LINE__, 0x3f847ab4, 0x83711936, 0x3f847ae1, 0x47ae16ad},	/* 0.00999967=f(0.01)*/
{36, 0,123,__LINE__, 0x3f947a2e, 0x5602b3cb, 0x3f947ae1, 0x47ae1594},	/* 0.0199973=f(0.02)*/
{36, 0,123,__LINE__, 0x3f9eb5f6, 0x38a0d3a8, 0x3f9eb851, 0xeb851fd2},	/* 0.029991=f(0.03)*/
{37, 0,123,__LINE__, 0x3fa47816, 0x1bcb9ce0, 0x3fa47ae1, 0x47ae1508},	/* 0.0399787=f(0.04)*/
{38, 0,123,__LINE__, 0x3fa99425, 0x9df4ef97, 0x3fa99999, 0x99999a27},	/* 0.0499584=f(0.05)*/
{36, 0,123,__LINE__, 0x3faeaee7, 0x293b5294, 0x3faeb851, 0xeb851f46},	/* 0.0599282=f(0.06)*/
{36, 0,123,__LINE__, 0x3fb1e40c, 0x8cbe24e8, 0x3fb1eb85, 0x1eb85232},	/* 0.069886=f(0.07)*/
{36, 0,123,__LINE__, 0x3fb46fbc, 0xe23e3843, 0x3fb47ae1, 0x47ae14c1},	/* 0.07983=f(0.08)*/
{36, 0,123,__LINE__, 0x3fb6fa64, 0x55ee5c13, 0x3fb70a3d, 0x70a3d750},	/* 0.0897582=f(0.09)*/
{38, 0,123,__LINE__, 0x3fb983e2, 0x8938f9ec, 0x3fb99999, 0x999999df},	/* 0.0996687=f(0.1)*/
{39, 0,123,__LINE__, 0x3fbc0c17, 0xd5ee1017, 0x3fbc28f5, 0xc28f5c6e},	/* 0.10956=f(0.11)*/
{38, 0,123,__LINE__, 0x3fbe92e4, 0xd816b510, 0x3fbeb851, 0xeb851efd},	/* 0.119429=f(0.12)*/
{37, 0,123,__LINE__, 0x3fc08c15, 0x4b37fcc9, 0x3fc0a3d7, 0x0a3d70c6},	/* 0.129275=f(0.13)*/
{39, 0,123,__LINE__, 0x3fc1cde5, 0x55175feb, 0x3fc1eb85, 0x1eb8520e},	/* 0.139096=f(0.14)*/
{36, 0,123,__LINE__, 0x3fc30ed3, 0x745c7ec6, 0x3fc33333, 0x33333356},	/* 0.14889=f(0.15)*/
{40, 0,123,__LINE__, 0x3fc44ed0, 0xc5b9e4fb, 0x3fc47ae1, 0x47ae149e},	/* 0.158655=f(0.16)*/
{36, 0,123,__LINE__, 0x3fc58dcf, 0x08b0cbf1, 0x3fc5c28f, 0x5c28f5e6},	/* 0.16839=f(0.17)*/
{39, 0,123,__LINE__, 0x3fc6cbbf, 0xe78dc0ed, 0x3fc70a3d, 0x70a3d72e},	/* 0.178093=f(0.18)*/
{36, 0,123,__LINE__, 0x3fc80895, 0x58e9b95a, 0x3fc851eb, 0x851eb876},	/* 0.187762=f(0.19)*/
{37, 0,123,__LINE__, 0x3fc94441, 0xff1e8881, 0x3fc99999, 0x999999be},	/* 0.197396=f(0.2)*/
{38, 0,123,__LINE__, 0x3fca7eb8, 0x52dd8b57, 0x3fcae147, 0xae147b06},	/* 0.206992=f(0.21)*/
{41, 0,123,__LINE__, 0x3fcbb7eb, 0x9c76b83b, 0x3fcc28f5, 0xc28f5c4e},	/* 0.21655=f(0.22)*/
{35, 0,123,__LINE__, 0x3fccefcf, 0x1f0e713a, 0x3fcd70a3, 0xd70a3d96},	/* 0.226068=f(0.23)*/
{36, 0,123,__LINE__, 0x3fce2656, 0x7792ede2, 0x3fceb851, 0xeb851ede},	/* 0.235545=f(0.24)*/
{37, 0,123,__LINE__, 0x3fcf5b75, 0xf92c80dd, 0x3fd00000, 0x00000013},	/* 0.244979=f(0.25)*/
{36, 0,123,__LINE__, 0x3fd04790, 0xed91143f, 0x3fd0a3d7, 0x0a3d70b7},	/* 0.254368=f(0.26)*/
{35, 0,123,__LINE__, 0x3fd0e0a7, 0xa4e2165e, 0x3fd147ae, 0x147ae15b},	/* 0.263712=f(0.27)*/
{35, 0,123,__LINE__, 0x3fd178f9, 0x8001d41a, 0x3fd1eb85, 0x1eb851ff},	/* 0.273009=f(0.28)*/
{36, 0,123,__LINE__, 0x3fd21081, 0x66d9dcb1, 0x3fd28f5c, 0x28f5c2a3},	/* 0.282257=f(0.29)*/
{37, 0,123,__LINE__, 0x3fd2a73a, 0x71dcec16, 0x3fd33333, 0x33333347},	/* 0.291457=f(0.3)*/
{36, 0,123,__LINE__, 0x3fd33d1f, 0x92caa76b, 0x3fd3d70a, 0x3d70a3eb},	/* 0.300606=f(0.31)*/
{37, 0,123,__LINE__, 0x3fd3d22c, 0x459ac510, 0x3fd47ae1, 0x47ae148f},	/* 0.309703=f(0.32)*/
{36, 0,123,__LINE__, 0x3fd4665c, 0x379e6ef3, 0x3fd51eb8, 0x51eb8533},	/* 0.318748=f(0.33)*/
{37, 0,123,__LINE__, 0x3fd4f9aa, 0xf181f793, 0x3fd5c28f, 0x5c28f5d7},	/* 0.327739=f(0.34)*/
{35, 0,123,__LINE__, 0x3fd58c14, 0x84f62c77, 0x3fd66666, 0x6666667b},	/* 0.336675=f(0.35)*/
{37, 0,123,__LINE__, 0x3fd61d95, 0x34fc23bb, 0x3fd70a3d, 0x70a3d71f},	/* 0.345556=f(0.36)*/
{37, 0,123,__LINE__, 0x3fd6ae29, 0x21408626, 0x3fd7ae14, 0x7ae147c3},	/* 0.35438=f(0.37)*/
{39, 0,123,__LINE__, 0x3fd73dcc, 0xf05da4a1, 0x3fd851eb, 0x851eb867},	/* 0.363147=f(0.38)*/
{36, 0,123,__LINE__, 0x3fd7cc7d, 0x5daadfdb, 0x3fd8f5c2, 0x8f5c290b},	/* 0.371856=f(0.39)*/
{35, 0,123,__LINE__, 0x3fd85a37, 0x70ebe7ae, 0x3fd99999, 0x999999af},	/* 0.380506=f(0.4)*/
{35, 0,123,__LINE__, 0x3fd8e6f8, 0x0f4c9bee, 0x3fda3d70, 0xa3d70a53},	/* 0.389097=f(0.41)*/
{38, 0,123,__LINE__, 0x3fd972bc, 0xa0ebf527, 0x3fdae147, 0xae147af7},	/* 0.397628=f(0.42)*/
{36, 0,123,__LINE__, 0x3fd9fd82, 0xbc57a5dd, 0x3fdb851e, 0xb851eb9b},	/* 0.406098=f(0.43)*/
{38, 0,123,__LINE__, 0x3fda8747, 0xd56eb412, 0x3fdc28f5, 0xc28f5c3f},	/* 0.414507=f(0.44)*/
{38, 0,123,__LINE__, 0x3fdb1009, 0xdf497c65, 0x3fdccccc, 0xcccccce3},	/* 0.422854=f(0.45)*/
{36, 0,123,__LINE__, 0x3fdb97c6, 0xf9406ab4, 0x3fdd70a3, 0xd70a3d87},	/* 0.431139=f(0.46)*/
{43, 0,123,__LINE__, 0x3fdc1e7d, 0x1f75747d, 0x3fde147a, 0xe147ae2b},	/* 0.439361=f(0.47)*/
{37, 0,123,__LINE__, 0x3fdca42a, 0xc909f465, 0x3fdeb851, 0xeb851ecf},	/* 0.44752=f(0.48)*/
{36, 0,123,__LINE__, 0x3fdd28ce, 0x96c784ce, 0x3fdf5c28, 0xf5c28f73},	/* 0.455616=f(0.49)*/
{36, 0,123,__LINE__, 0x3fddac67, 0x0561bb4f, 0x3fe00000, 0x0000000b},	/* 0.463648=f(0.5)*/
{39, 0,123,__LINE__, 0x3fde2ef3, 0x07efdc1b, 0x3fe051eb, 0x851eb85d},	/* 0.471616=f(0.51)*/
{39, 0,123,__LINE__, 0x3fdeb071, 0x9f1b3dcf, 0x3fe0a3d7, 0x0a3d70af},	/* 0.479519=f(0.52)*/
{38, 0,123,__LINE__, 0x3fdf30e1, 0xf21de795, 0x3fe0f5c2, 0x8f5c2901},	/* 0.487359=f(0.53)*/
{35, 0,123,__LINE__, 0x3fdfb043, 0x7f47297b, 0x3fe147ae, 0x147ae153},	/* 0.495133=f(0.54)*/
{39, 0,123,__LINE__, 0x3fe0174a, 0xaa285063, 0x3fe19999, 0x999999a5},	/* 0.502843=f(0.55)*/
{38, 0,123,__LINE__, 0x3fe055eb, 0x9bed5ef9, 0x3fe1eb85, 0x1eb851f7},	/* 0.510488=f(0.56)*/
{37, 0,123,__LINE__, 0x3fe09404, 0x7073e5d6, 0x3fe23d70, 0xa3d70a49},	/* 0.518069=f(0.57)*/
{37, 0,123,__LINE__, 0x3fe0d195, 0x13df3464, 0x3fe28f5c, 0x28f5c29b},	/* 0.525584=f(0.58)*/
{38, 0,123,__LINE__, 0x3fe10e9d, 0x8269ecb9, 0x3fe2e147, 0xae147aed},	/* 0.533034=f(0.59)*/
{39, 0,123,__LINE__, 0x3fe14b1d, 0xdf627649, 0x3fe33333, 0x3333333f},	/* 0.54042=f(0.6)*/
{38, 0,123,__LINE__, 0x3fe18716, 0x164cc043, 0x3fe3851e, 0xb851eb91},	/* 0.54774=f(0.61)*/
{38, 0,123,__LINE__, 0x3fe1c286, 0x68243c6c, 0x3fe3d70a, 0x3d70a3e3},	/* 0.554996=f(0.62)*/
{39, 0,123,__LINE__, 0x3fe1fd6f, 0x0c144c54, 0x3fe428f5, 0xc28f5c35},	/* 0.562187=f(0.63)*/
{40, 0,123,__LINE__, 0x3fe237d0, 0x46abe6ab, 0x3fe47ae1, 0x47ae1487},	/* 0.569313=f(0.64)*/
{37, 0,123,__LINE__, 0x3fe271aa, 0x6955b200, 0x3fe4cccc, 0xccccccd9},	/* 0.576375=f(0.65)*/
{39, 0,123,__LINE__, 0x3fe2aafd, 0xe81bd50c, 0x3fe51eb8, 0x51eb852b},	/* 0.583373=f(0.66)*/
{38, 0,123,__LINE__, 0x3fe2e3ca, 0xffc55cd9, 0x3fe570a3, 0xd70a3d7d},	/* 0.590307=f(0.67)*/
{38, 0,123,__LINE__, 0x3fe31c12, 0x3bae5fc0, 0x3fe5c28f, 0x5c28f5cf},	/* 0.597177=f(0.68)*/
{38, 0,123,__LINE__, 0x3fe353d4, 0x1b8000de, 0x3fe6147a, 0xe147ae21},	/* 0.603983=f(0.69)*/
{38, 0,123,__LINE__, 0x3fe38b11, 0x29303bc3, 0x3fe66666, 0x66666673},	/* 0.610726=f(0.7)*/
{39, 0,123,__LINE__, 0x3fe3c1c9, 0xf8850ff6, 0x3fe6b851, 0xeb851ec5},	/* 0.617406=f(0.71)*/
{38, 0,123,__LINE__, 0x3fe3f7ff, 0x3bad3381, 0x3fe70a3d, 0x70a3d717},	/* 0.624023=f(0.72)*/
{42, 0,123,__LINE__, 0x3fe42db1, 0x6e4875a8, 0x3fe75c28, 0xf5c28f69},	/* 0.630578=f(0.73)*/
{40, 0,123,__LINE__, 0x3fe462e1, 0x53fea64b, 0x3fe7ae14, 0x7ae147bb},	/* 0.63707=f(0.74)*/
{39, 0,123,__LINE__, 0x3fe4978f, 0xa3269ee1, 0x3fe80000, 0x0000000d},	/* 0.643501=f(0.75)*/
{37, 0,123,__LINE__, 0x3fe4cbbd, 0x199cb989, 0x3fe851eb, 0x851eb85f},	/* 0.64987=f(0.76)*/
{38, 0,123,__LINE__, 0x3fe4ff6a, 0x7c55a213, 0x3fe8a3d7, 0x0a3d70b1},	/* 0.656179=f(0.77)*/
{40, 0,123,__LINE__, 0x3fe53298, 0x96f3ffb4, 0x3fe8f5c2, 0x8f5c2903},	/* 0.662426=f(0.78)*/
{40, 0,123,__LINE__, 0x3fe56548, 0x4f150748, 0x3fe947ae, 0x147ae155},	/* 0.668614=f(0.79)*/
{41, 0,123,__LINE__, 0x3fe5977a, 0x54eaf0d0, 0x3fe99999, 0x999999a7},	/* 0.674741=f(0.8)*/
{39, 0,123,__LINE__, 0x3fe5c92f, 0x99a68d3b, 0x3fe9eb85, 0x1eb851f9},	/* 0.680809=f(0.81)*/
{41, 0,123,__LINE__, 0x3fe5fa68, 0xffb51ff8, 0x3fea3d70, 0xa3d70a4b},	/* 0.686818=f(0.82)*/
{39, 0,123,__LINE__, 0x3fe62b27, 0x6e49e7a0, 0x3fea8f5c, 0x28f5c29d},	/* 0.692768=f(0.83)*/
{40, 0,123,__LINE__, 0x3fe65b6b, 0xd10553f8, 0x3feae147, 0xae147aef},	/* 0.69866=f(0.84)*/
{42, 0,123,__LINE__, 0x3fe68b37, 0x2a33099d, 0x3feb3333, 0x33333341},	/* 0.704494=f(0.85)*/
{42, 0,123,__LINE__, 0x3fe6ba8a, 0x47f8aa01, 0x3feb851e, 0xb851eb93},	/* 0.710271=f(0.86)*/
{41, 0,123,__LINE__, 0x3fe6e966, 0x3409a5e1, 0x3febd70a, 0x3d70a3e5},	/* 0.715991=f(0.87)*/
{40, 0,123,__LINE__, 0x3fe717cb, 0xe87d80d6, 0x3fec28f5, 0xc28f5c37},	/* 0.721655=f(0.88)*/
{42, 0,123,__LINE__, 0x3fe745bc, 0x62486ac9, 0x3fec7ae1, 0x47ae1489},	/* 0.727263=f(0.89)*/
{41, 0,123,__LINE__, 0x3fe77338, 0xa0f3a0bc, 0x3feccccc, 0xccccccdb},	/* 0.732815=f(0.9)*/
{40, 0,123,__LINE__, 0x3fe7a041, 0xb7d9b23c, 0x3fed1eb8, 0x51eb852d},	/* 0.738313=f(0.91)*/
{43, 0,123,__LINE__, 0x3fe7ccd8, 0x87b34764, 0x3fed70a3, 0xd70a3d7f},	/* 0.743756=f(0.92)*/
{40, 0,123,__LINE__, 0x3fe7f8fe, 0x27e4271c, 0x3fedc28f, 0x5c28f5d1},	/* 0.749145=f(0.93)*/
{42, 0,123,__LINE__, 0x3fe824b3, 0x9fb39920, 0x3fee147a, 0xe147ae23},	/* 0.75448=f(0.94)*/
{41, 0,123,__LINE__, 0x3fe84ff9, 0xf7bff26b, 0x3fee6666, 0x66666675},	/* 0.759763=f(0.95)*/
{41, 0,123,__LINE__, 0x3fe87ad2, 0x39c6a5ae, 0x3feeb851, 0xeb851ec7},	/* 0.764993=f(0.96)*/
{42, 0,123,__LINE__, 0x3fe8a53d, 0x80eb7985, 0x3fef0a3d, 0x70a3d719},	/* 0.770171=f(0.97)*/
{42, 0,123,__LINE__, 0x3fe8cf3c, 0xb7688432, 0x3fef5c28, 0xf5c28f6b},	/* 0.775298=f(0.98)*/
{44, 0,123,__LINE__, 0x3fe8f8d0, 0xf9c806ac, 0x3fefae14, 0x7ae147bd},	/* 0.780373=f(0.99)*/
{64, 0,123,__LINE__, 0x3fe921fb, 0x54442d18, 0x3ff00000, 0x00000007},	/* 0.785398=f(1)*/
{43, 0,123,__LINE__, 0x3fe94abc, 0xd341c3fc, 0x3ff028f5, 0xc28f5c30},	/* 0.790373=f(1.01)*/
{44, 0,123,__LINE__, 0x3fe97316, 0x8325efd2, 0x3ff051eb, 0x851eb859},	/* 0.795299=f(1.02)*/
{43, 0,123,__LINE__, 0x3fe99b09, 0x702df464, 0x3ff07ae1, 0x47ae1482},	/* 0.800175=f(1.03)*/
{41, 0,123,__LINE__, 0x3fe9c296, 0xa648fc14, 0x3ff0a3d7, 0x0a3d70ab},	/* 0.805003=f(1.04)*/
{41, 0,123,__LINE__, 0x3fe9e9bf, 0x30f3cf55, 0x3ff0cccc, 0xccccccd4},	/* 0.809784=f(1.05)*/
{42, 0,123,__LINE__, 0x3fea1084, 0x1b166c9a, 0x3ff0f5c2, 0x8f5c28fd},	/* 0.814516=f(1.06)*/
{42, 0,123,__LINE__, 0x3fea36e6, 0x8cba06da, 0x3ff11eb8, 0x51eb8526},	/* 0.819202=f(1.07)*/
{40, 0,123,__LINE__, 0x3fea5ce7, 0x53440a81, 0x3ff147ae, 0x147ae14f},	/* 0.823841=f(1.08)*/
{41, 0,123,__LINE__, 0x3fea8287, 0x9544b647, 0x3ff170a3, 0xd70a3d78},	/* 0.828434=f(1.09)*/
{44, 0,123,__LINE__, 0x3feaa7c8, 0x5a1c3ad1, 0x3ff19999, 0x999999a1},	/* 0.832981=f(1.1)*/
{40, 0,123,__LINE__, 0x3feaccaa, 0xa804020a, 0x3ff1c28f, 0x5c28f5ca},	/* 0.837484=f(1.11)*/
{40, 0,123,__LINE__, 0x3feaf12f, 0x83f648d5, 0x3ff1eb85, 0x1eb851f3},	/* 0.841942=f(1.12)*/
{40, 0,123,__LINE__, 0x3feb1557, 0xf1973031, 0x3ff2147a, 0xe147ae1c},	/* 0.846355=f(1.13)*/
{40, 0,123,__LINE__, 0x3feb3924, 0xf31f37a6, 0x3ff23d70, 0xa3d70a45},	/* 0.850726=f(1.14)*/
{41, 0,123,__LINE__, 0x3feb5c97, 0x8947134c, 0x3ff26666, 0x6666666e},	/* 0.855053=f(1.15)*/
{39, 0,123,__LINE__, 0x3feb7fb0, 0xb334cfe9, 0x3ff28f5c, 0x28f5c297},	/* 0.859337=f(1.16)*/
{39, 0,123,__LINE__, 0x3feba271, 0x6e6a37ff, 0x3ff2b851, 0xeb851ec0},	/* 0.863579=f(1.17)*/
{39, 0,123,__LINE__, 0x3febc4da, 0xb6b46cf5, 0x3ff2e147, 0xae147ae9},	/* 0.86778=f(1.18)*/
{40, 0,123,__LINE__, 0x3febe6ed, 0xa099d4f5, 0x3ff30a3d, 0x70a3d712},	/* 0.871939=f(1.19)*/
{39, 0,123,__LINE__, 0xbff69b81, 0x55e3c935, 0xc01921fb, 0x54442d18},	/* -1.41297=f(-6.28319)*/
{38, 0,123,__LINE__, 0xbff5c97d, 0x37fcda82, 0xc012d97c, 0x7f3321d2},	/* -1.36169=f(-4.71239)*/
{38, 0,123,__LINE__, 0xbff433b8, 0xa54b916d, 0xc00921fb, 0x54442d18},	/* -1.26263=f(-3.14159)*/
{41, 0,123,__LINE__, 0xbff00fe9, 0x8b4f50d9, 0xbff921fb, 0x54442d18},	/* -1.00388=f(-1.5708)*/
{64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},	/* 0=f(0)*/
{41, 0,123,__LINE__, 0x3ff00fe9, 0x8b4f50d9, 0x3ff921fb, 0x54442d18},	/* 1.00388=f(1.5708)*/
{38, 0,123,__LINE__, 0x3ff433b8, 0xa54b916d, 0x400921fb, 0x54442d18},	/* 1.26263=f(3.14159)*/
{38, 0,123,__LINE__, 0x3ff5c97d, 0x37fcda82, 0x4012d97c, 0x7f3321d2},	/* 1.36169=f(4.71239)*/
{42, 0,123,__LINE__, 0xbff8997f, 0xbb8b19c0, 0xc03e0000, 0x00000000},	/* -1.53748=f(-30)*/
{41, 0,123,__LINE__, 0xbff8914e, 0x95177fa1, 0xc03c4ccc, 0xcccccccd},	/* -1.53548=f(-28.3)*/
{44, 0,123,__LINE__, 0xbff88811, 0xbc0bdc43, 0xc03a9999, 0x9999999a},	/* -1.53322=f(-26.6)*/
{40, 0,123,__LINE__, 0xbff87d92, 0x75fe4ff4, 0xc038e666, 0x66666667},	/* -1.53066=f(-24.9)*/
{41, 0,123,__LINE__, 0xbff8718a, 0x0c82b156, 0xc0373333, 0x33333334},	/* -1.52772=f(-23.2)*/
{41, 0,123,__LINE__, 0xbff8639b, 0x79e21172, 0xc0358000, 0x00000001},	/* -1.52432=f(-21.5)*/
{43, 0,123,__LINE__, 0xbff85349, 0xe70d6241, 0xc033cccc, 0xccccccce},	/* -1.52033=f(-19.8)*/
{43, 0,123,__LINE__, 0xbff83fe9, 0xca9ad5bc, 0xc0321999, 0x9999999b},	/* -1.5156=f(-18.1)*/
{40, 0,123,__LINE__, 0xbff82888, 0xd4b5183b, 0xc0306666, 0x66666668},	/* -1.5099=f(-16.4)*/
{40, 0,123,__LINE__, 0xbff80bc5, 0x5b635ed0, 0xc02d6666, 0x6666666a},	/* -1.50287=f(-14.7)*/
{39, 0,123,__LINE__, 0xbff7e786, 0x2aa0157c, 0xc02a0000, 0x00000004},	/* -1.49402=f(-13)*/
{39, 0,123,__LINE__, 0xbff7b872, 0x19e1f11e, 0xc0269999, 0x9999999e},	/* -1.48253=f(-11.3)*/
{40, 0,123,__LINE__, 0xbff778d9, 0x2d202791, 0xc0233333, 0x33333338},	/* -1.467=f(-9.6)*/
{39, 0,123,__LINE__, 0xbff71e3e, 0x5f93f1ef, 0xc01f9999, 0x999999a3},	/* -1.44488=f(-7.9)*/
{39, 0,123,__LINE__, 0xbff692fa, 0x42d530ee, 0xc018cccc, 0xccccccd6},	/* -1.41088=f(-6.2)*/
{38, 0,123,__LINE__, 0xbff5a250, 0x52114e60, 0xc0120000, 0x00000009},	/* -1.35213=f(-4.5)*/
{40, 0,123,__LINE__, 0xbff3a4f4, 0xa6f3dda7, 0xc0066666, 0x66666678},	/* -1.22777=f(-2.8)*/
{44, 0,123,__LINE__, 0xbfeaa7c8, 0x5a1c3ad1, 0xbff19999, 0x999999bd},	/* -0.832981=f(-1.1)*/
{39, 0,123,__LINE__, 0x3fe14b1d, 0xdf627649, 0x3fe33333, 0x333332ec},	/* 0.54042=f(0.6)*/
{37, 0,123,__LINE__, 0x3ff29219, 0xa28e156e, 0x40026666, 0x66666654},	/* 1.16067=f(2.3)*/
{40, 0,123,__LINE__, 0x3ff5368c, 0x951e9cfd, 0x400fffff, 0xffffffee},	/* 1.32582=f(4)*/
{39, 0,123,__LINE__, 0x3ff65a9f, 0xdf6aa710, 0x4016cccc, 0xccccccc4},	/* 1.39713=f(5.7)*/
{39, 0,123,__LINE__, 0x3ff6fbcd, 0x17344683, 0x401d9999, 0x99999991},	/* 1.43647=f(7.4)*/
{41, 0,123,__LINE__, 0x3ff761ab, 0xb20bb4ef, 0x40223333, 0x3333332f},	/* 1.46135=f(9.1)*/
{41, 0,123,__LINE__, 0x3ff7a7cd, 0x01a174a0, 0x40259999, 0x99999995},	/* 1.47847=f(10.8)*/
{40, 0,123,__LINE__, 0x3ff7daff, 0x85a63058, 0x4028ffff, 0xfffffffb},	/* 1.49097=f(12.5)*/
{40, 0,123,__LINE__, 0x3ff80201, 0xa8421a8e, 0x402c6666, 0x66666661},	/* 1.50049=f(14.2)*/
{41, 0,123,__LINE__, 0x3ff820b5, 0xe634e62f, 0x402fcccc, 0xccccccc7},	/* 1.50799=f(15.9)*/
{43, 0,123,__LINE__, 0x3ff83981, 0x230df9a0, 0x40319999, 0x99999997},	/* 1.51404=f(17.6)*/
{41, 0,123,__LINE__, 0x3ff84df1, 0x8157a52b, 0x40334ccc, 0xccccccca},	/* 1.51903=f(19.3)*/
{45, 0,123,__LINE__, 0x3ff85f14, 0xd43d81be, 0x4034ffff, 0xfffffffd},	/* 1.52321=f(21)*/
{42, 0,123,__LINE__, 0x3ff86da8, 0x66ecad32, 0x4036b333, 0x33333330},	/* 1.52677=f(22.7)*/
{40, 0,123,__LINE__, 0x3ff87a34, 0xf054fde4, 0x40386666, 0x66666663},	/* 1.52984=f(24.4)*/
{41, 0,123,__LINE__, 0x3ff8851f, 0xa545638f, 0x403a1999, 0x99999996},	/* 1.5325=f(26.1)*/
{41, 0,123,__LINE__, 0x3ff88eb5, 0x05d253be, 0x403bcccc, 0xccccccc9},	/* 1.53484=f(27.8)*/
{41, 0,123,__LINE__, 0x3ff8972f, 0xfc482372, 0x403d7fff, 0xfffffffc},	/* 1.53691=f(29.5)*/
{0},
};
void test_atanf(int m)   {run_vector_1(m,atanf_vec,(char *)(atanf),"atanf","ff");   }	
